/*
 PlayAreaView.h
 jigplay-macos

 Created by François Pessaux on 16/09/10.
 Copyright 2010. All rights reserved.
*/

#import <Cocoa/Cocoa.h>
#include "misc.h"


@interface PlayAreaView : NSView {
  IBOutlet NSWindow *mainWindow ;
  IBOutlet NSMenuItem *saveMenuItem ;
  IBOutlet NSMenuItem *arrangePiecesMenuItem ;
  IBOutlet NSMenuItem *changeBackgroundMenuItem ;
  IBOutlet NSMenuItem *showImageMenuItem ;
  IBOutlet NSMenuItem *toggleImageHintMenuItem ;
  IBOutlet NSMenuItem *toggleBordersHintMenuItem ;
  /* Set once a game is started and the view dimensions are set according to
     the size of the picture. */
  int maxViewWidth ;
  int maxViewHeight ;
  CALayer *playAreaRootLayer ;
  CALayer *transpImageHintLayer ;
  /* Indexed by the piece piece_debug_id. So the piece_debug_ids must be
     dense. */
  CALayer **piecesLayers ;
  struct game *current_game ;
  struct piece *holdPiece ;
  bool_t bordersHighlighted ;
}

- (void) initGamePiecesLayers: (struct game*) game ;
- (void) partialUpdateDisplay: (struct game*) game
                     fromPiece: (struct piece*) from_piece ;
- (void) freeGamePiecesLayers: (struct game*) game ;
- (void) startNewGame: (const char*) image_file_name
          withHorizPieces: (int) nb_horiz_pieces
           withVertPieces: (int) nb_vert_pieces
      withScaleFactor: (float) scale_factor
      withWindowWidth: (int) window_width
     withWindowHeight: (int) window_height ;
- (void) changeBackgroundColor: (NSColor*) color ;
- (IBAction) arrangePiecesOnBordersCallback: (id) sender ;
- (struct game*) getCurrentGame ;
- (IBAction) toggleImageHintCallback: (id) sender ;
- (IBAction) saveGameCallback: (id) sender ;
- (IBAction) loadGameCallback: (id) sender ;
- (IBAction) highlightBordersCallback : (id) sender ;

@end
